pub fn execute_sequences(
scratch: &mut DecoderScratch,
) -> Result<(), ExecuteSequencesError>Expand description
Take the provided decoder and execute the sequences stored within
pub fn execute_sequences(
scratch: &mut DecoderScratch,
) -> Result<(), ExecuteSequencesError>Take the provided decoder and execute the sequences stored within